Archive of Supreme Court Opinions - 2013
Keywords: Connecticut, Judicial, Civil, Opinion, Criminal, Law Libraries, Juror, Jury, Victim, Small Claims, Justice, Supreme, Trial, Appellate, Court, Judical, Attorney, Judge, Court, docket, Housing, Landlord, Grievance, Bar Exam, Legal, Probate, Superior, Magistrate, Marshal

Archive of Supreme Court Opinions 2014 2013 | 2012 | 2011 | 2010 | 2009 | 2008 | 2007 | 2006 | 2005 | 2004 | 2003 | 2002 | 2001 | 2000
To Search: | Hit Control, F, on your keyboard, and enter the name, or use the browser menu and select edit, then find.
Information on how to purchase the Connecticut Law Journal or Connecticut Reports |
Quick Links
Advance Release Opinions
Appellate Court Archive
Memorandum Archive
Supreme Court Archive
To be Published in Connecticut Law Journal of 7/29/14: SC18939 - Mueller v. Tepler To be Published in Connecticut Law Journal of 7/22/14: SC18887 - State v. Buie SC19213 - State v. Henderson SC18942, SC18993, SC18994 - Perry v. Perry Published in Connecticut Law Journal of 7/15/14: SC19047 - Commissioner of Public Safety v. Freedom of Information Commission SC18946 - State v. Ortiz Published in Connecticut Law Journal of 7/8/14: SC18819 - Single Source, Inc. v. Central Regional Tourism District, Inc. SC18980 - Frank v. Dept. of Children & Families SC18452 - Reville v. Reville SC18452 Concurrence - Reville v. Reville Published in Connecticut Law Journal of 7/1/14: SC19101 - Cannizzaro v. Marinyak SC18940 - Rodriguez v. Commissioner of Correction Published in Connecticut Law Journal of 6/24/14: SC19009 - Connecticut Independent Utility Workers, Local 12924 v. Dept. of Public Utility Control SC19154 - Coyle v. Commissioner of Revenue Services SC18821 - Flannery v. Singer Asset Finance Co., LLC SC18821 Dissent - Flannery v. Singer Asset Finance Co., LLC Published in Connecticut Law Journal of 6/17/14: SC19092 - Stafford v. Roadway SC19044 - Palomba-Bourke v. Commissioner of Social Services SC18981 - Taylor v. Commissioner of Correction SC19178 - State v. Wang Published in Connecticut Law Journal of 6/10/14: SC18793 - Kortner v. Martise SC18793 Concurrence - Kortner v. Martise SC18793 Concurrence - Kortner v. Martise SC18793 Concurrence - Kortner v. Martise SC18207 - State v. Shaw SC18207 Dissent - State v. Shaw SC19014 - State v. Smalls SC19129 - Coley v. Hartford SC19129 Dissent - Coley v. Hartford Published in Connecticut Law Journal of 6/3/14: SC18737 - State v. Elson SC18633 - State v. Baltas Published in Connecticut Law Journal of 5/27/14: SC18961 - Robbins v. Physicians for Women's Health, LLC Published in Connecticut Law Journal of 5/20/14: SC18789 - Pack 2000, Inc. v. Cushman SC18789 Dissent - Pack 2000, Inc. v. Cushman Published in Connecticut Law Journal of 5/6/14: SC18937 - Gagne v. Vaccaro Published in Connecticut Law Journal of 4/29/14: SC18877 - Sarrazin v. Coastal, Inc. SC18877 Concurrence - Sarrazin v. Coastal, Inc. SC19103 - State v. Williams Published in Connecticut Law Journal of 4/22/14: SC18864 - State v. Davis SC18864 Concurrence - State v. Davis SC18864 Concurrence - State v. Davis SC19082 - State v. Pierre SC18738 - State v. DeMarco SC18738 Dissent - State v. DeMarco Published in Connecticut Law Journal of 4/15/14: SC19100 - Greenwald v. Van Handel SC19100 Dissent - Greenwald v. Van Handel SC18991 - State v. Gonzalez SC19192 - State Grievance Committee v. Ganim Published in Connecticut Law Journal of 4/8/14: SC19069 - Reardon v. Zoning Board of Appeals Published in Connecticut Law Journal of 4/1/14: SC18996 - Meyers v. Livingston, Adler, Pulda, Meiklejohn & Kelly, P.C. SC18949 - Vendrella v. Astriab Family Ltd. Partnership SC18949 Concurrence - Vendrella v. Astriab Family Ltd. Partnership Published in Connecticut Law Journal of 3/25/14: SC19107 - Citizens Against Overhead Power Line Construction v. Connecticut Siting Council SC19046 - Commissioner of Public Health v. Freedom of Information Commission Published in Connecticut Law Journal of 3/18/14: SC19095 - Edgerton v. Clinton SC19095 Dissent - Edgerton v. Clinton Published in Connecticut Law Journal of 3/4/14: SC18842 - State v. Mangual Published in Connecticut Law Journal of 2/18/14: SC18911 - Blumberg Associates Worldwide, Inc. v. Brown & Brown of Connecticut, Inc. Published in Connecticut Law Journal of 2/11/14: SC19015 - Cruz v. Visual Perceptions, LLC SC19015 Dissent - Cruz v. Visual Perceptions, LLC SC18956 - Yellow Book Sales & Distribution Co. v. Valle Published in Connecticut Law Journal of 1/28/14: SC18879 - State v. Allan SC18681, SC18682 - Lexington Ins. Co. v. Lexington Healthcare Group, Inc. SC18681, SC18682 Dissent - Lexington Ins. Co. v. Lexington Healthcare Group, Inc. SC18945 - State v. Rodriguez Published in Connecticut Law Journal of 1/21/14: SC18917 - Fairchild Heights Residents Association, Inc. v. Fairchild Heights, Inc. SC18957 - State v. Baptiste Published in Connecticut Law Journal of 1/7/14: SC18855 - Rawls v. Progressive Northern Ins. Co.
Attorneys | Case Look-up | Courts | Directories | Educational Resources | E-Services | Español | FAQ's | Juror Information | Media | Opinions | Opportunities | Self-Help | Home Common Legal Words | Contact Us | Site Map | Website Polices and Disclaimers Copyright © 2014, State of Connecticut Judicial Branch